---
title: <span class="badge object-type-scalar"></span> TeraHashesPerSecond
---
# <span class="badge object-type-scalar"></span> TeraHashesPerSecond

Hash rate: terahashes/sec

## Definition

```python
# Hash rate: terahashes/sec
TeraHashesPerSecond: typing.Literal["THs"] = "THs"
```
